@@ -6,15 +6,22 @@ from holmes.validators.base import Validator
 
 class MetaTagsValidator(Validator):
 
+    @classmethod
+    def get_violation_definitions(cls):
+        return {
+            'absent.metatags': {
+                'title': 'Meta tags not present.',
+                'description': lambda value: "No meta tags found on this page. This is damaging for Search Engines."
+            }
+        }
+
     def validate(self):
         meta_tags = self.get_meta_tags()
 
         if not meta_tags:
             self.add_violation(
                 key='absent.metatags',
-                title='Meta tags not present',
-                description='Not having meta tags is damaging for '
-                            'Search Engines.',
+                value='No metatags.',
                 points=100
             )
 
